from typing import FrozenSet

empty_tags: FrozenSet[str]
deprecated_tags: FrozenSet[str]
link_attrs: FrozenSet[str]
event_attrs: FrozenSet[str]
safe_attrs: FrozenSet[str]
top_level_tags: FrozenSet[str]
head_tags: FrozenSet[str]
general_block_tags: FrozenSet[str]
list_tags: FrozenSet[str]
table_tags: FrozenSet[str]
block_tags: FrozenSet[str]
form_tags: FrozenSet[str]
special_inline_tags: FrozenSet[str]
phrase_tags: FrozenSet[str]
font_style_tags: FrozenSet[str]
frame_tags: FrozenSet[str]
html5_tags: FrozenSet[str]
nonstandard_tags: FrozenSet[str]
tags: FrozenSet[str]



from typing import Any, Dict, List, Optional, Union

from lxml import etree

# dummy for missing stubs
def __getattr__(name) -> Any: ...

_DictAnyStr = Union[Dict[str, str], Dict[bytes, bytes]]

class CSSSelector(etree.XPath):
    def __init__(
        self, css: str, namespaces: Optional[_DictAnyStr] = ..., translator: str = ...
    ): ...
    def __call__(self, element: etree._Element) -> List[etree._Element]: ...



import re

from setuptools import setup

tests_require = [
    "pytest>=6.0.0",
    "pytest-mypy-plugins==1.4.0",
    "coverage[toml]==5.2",
]

with open("README.md") as fh:
    long_description = re.sub(
        "<!-- start-no-pypi -->.*<!-- end-no-pypi -->\n",
        "",
        fh.read(),
        flags=re.M | re.S,
    )

setup(
    name="lxml-stubs",
    version="0.3.0",
    description="Type annotations for the lxml package",
    long_description=long_description,
    long_description_content_type="text/markdown",
    package_data={"lxml-stubs": ["*.pyi", "*/*.pyi"]},
    packages=["lxml-stubs"],
    tests_require=tests_require,
    extras_require={"test": tests_require},
    classifiers=[
        "License :: OSI Approved :: Apache Software License",
    ],
    zip_safe=False
)
